pub struct ResultCode(/* private fields */);Implementations
Sourceimpl ResultCode
impl ResultCode
Sourcepub const OK: Self
pub const OK: Self
Indicates that the last operation was successful or operation is in progress.
Sourcepub const ERR_PRODUCT: Self
pub const ERR_PRODUCT: Self
Indicates that the AC is not for the current product/version.
Sourcepub const ERR_PRODUCT_PH2: Self
pub const ERR_PRODUCT_PH2: Self
Indicates that the AC in the second phase is not for the current product/version.
Sourcepub const ERR_TRANSFER: Self
pub const ERR_TRANSFER: Self
Indicates that the AC is corrupted.
Sourcepub const ERR_TRANSFER_PH2: Self
pub const ERR_TRANSFER_PH2: Self
Indicates that the AC in the second phase is corrupted.
Sourcepub const ERR_AUTH_PH2: Self
pub const ERR_AUTH_PH2: Self
Indicates that the authentication of the provided AC failed in the second phase.
Sourcepub const ERR_PUF_QUALITY: Self
pub const ERR_PUF_QUALITY: Self
Indicates that the SRAM PUF quality verification fails.
Sourcepub const ERR_CONTEXT: Self
pub const ERR_CONTEXT: Self
Indicates that the incorrect or unsupported context is provided.
Sourcepub const ERR_DESTINATION: Self
pub const ERR_DESTINATION: Self
Indicates that a data destination was set that is not allowed according to other settings and the current PUF state.
Sourceimpl ResultCode
impl ResultCode